@@ -24,6 +24,8 @@ async def async_common_request(method, url, params=None, data=None, json=None,
                 result = await resp.json()
             elif result_type == "text":
                 result = await resp.text
+            elif result_type == "origin":
+                return resp
             else:
                 result = await resp.content.read()
             return result
@@ -44,6 +46,8 @@ def sync_common_request(method, url, params=None, data=None, json=None, result_t
                 result = res.json()
             elif result_type == "text":
                 result = res.text
+            elif result_type == "origin":
+                return res
             else:
                 result = res.content
             return result
